{
  lib,
  pkgs,
  config,
  ...
}:
{
  imports = [ ../rofi ];

  services.dunst.enable = true;

  programs = {
    i3status-rust = {
      enable = true;
    };
  };
  home.packages = with pkgs; [
    nitrogen
    xfce.xfce4-screenshooter
    pulseaudio # For pactl commands
  ];
  xsession.enable = true; # Give gui programs access to sessionVariables
  # Prevent screen from going blank (check these settings with `xset q`)
  # And disable bell sound (b)
  xsession.initExtra = ''
    ${pkgs.xorg.xset}/bin/xset s off
    ${pkgs.xorg.xset}/bin/xset -dpms
    ${pkgs.xorg.xset}/bin/xset b off
  '';
  xsession.windowManager.i3 = {
    enable = true;
    package = pkgs.i3-gaps;
  };

  xsession.importedVariables = [ ];

  # Overwrite default home-manager config file
  xdg.configFile."i3/config".source = lib.mkForce (
    if config.hostName == "kardorf" then ./i3/config-kardorf else ./i3/config
  );

  home.file = {
    ".config/i3/scripts" = {
      source = ./i3/scripts;
      recursive = true;
    };
    ".config/i3/workspace-messaging.json".source = ./i3/workspace-chat-element-tele.json;
    ".config/i3status-rust/config.toml".source = ./i3status-rust/config.toml;
  };

  home.sessionPath = [ "/home/julian/.config/i3/scripts" ];
}
